@@ -26,22 +26,29 @@
 #include <string.h>
 
 #include <glib.h>
+#include <gdk/gdkx.h>
 #include <gtk/gtk.h>
+#include <gtk/gtkx.h>
+
+#ifdef XFCONF_LEGACY
 #include <dbus/dbus-glib.h>
+#endif
 #include <libwnck/libwnck.h>
 
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
 #include <xfconf/xfconf.h>
+
+#include <common/xfwm-common.h>
+
 #include "xfwm4-workspace-dialog_ui.h"
-#include "monitor-icon.h"
 
 #define WORKSPACES_CHANNEL         "xfwm4"
 
 #define WORKSPACE_NAMES_PROP       "/general/workspace_names"
 #define WORKSPACE_COUNT_PROP       "/general/workspace_count"
 
-static GdkNativeWindow opt_socket_id = 0;
+static Window opt_socket_id = 0;
 static gboolean opt_version = FALSE;
 
 
@@ -211,8 +218,12 @@ xfconf_workspace_names_changed(XfconfChannel *channel,
 {
     GPtrArray *names;
 
+#ifdef XFCONF_LEGACY
     if(G_VALUE_TYPE(value) !=  dbus_g_type_get_collection("GPtrArray",
                                                           G_TYPE_VALUE))
+#else
+    if(G_VALUE_TYPE(value) != G_TYPE_PTR_ARRAY)
+#endif
     {
         g_warning("(workspace names) Expected boxed GPtrArray property, got %s",
                   G_VALUE_TYPE_NAME(value));
@@ -296,6 +307,8 @@ workspace_dialog_setup_names_treeview(GtkBuilder *builder,
                      G_CALLBACK(xfconf_workspace_names_changed), treeview);
 }
 
+
+
 static void
 workspace_dialog_configure_widgets (GtkBuilder *builder,
                                     XfconfChannel *channel)
@@ -315,14 +328,18 @@ workspace_dialog_configure_widgets (GtkBuilder *builder,
     GtkWidget *margin_left_spinbutton = GTK_WIDGET (gtk_builder_get_object (builder, "margin_left_spinbutton"));
 
     /* Set monitor icon */
-    monitor = gdk_pixbuf_new_from_inline (-1, monitor_icon_data, TRUE, NULL);
-    image = GTK_WIDGET (gtk_builder_get_object (builder, "monitor_icon"));
-    gtk_image_set_from_pixbuf (GTK_IMAGE (image), monitor);
-    g_object_unref (monitor);
+    monitor = gdk_pixbuf_new_from_resource ("/org/xfce/xfwm4/monitor-icon.pixdata", NULL);
+    if(G_LIKELY (monitor != NULL))
+    {
+        image = GTK_WIDGET (gtk_builder_get_object (builder, "monitor_icon"));
+        gtk_image_set_from_pixbuf (GTK_IMAGE (image), monitor);
+        g_object_unref (monitor);
+    }
 
     /* Set max margins range */
-    wmax = gdk_screen_width () / 4;
-    hmax = gdk_screen_height () / 4;
+    xfwm_get_screen_dimensions (&wmax, &hmax);
+    wmax /= 4;
+    hmax /= 4;
 
     gtk_spin_button_set_range (GTK_SPIN_BUTTON (margin_top_spinbutton), 0, hmax);
     gtk_spin_button_set_range (GTK_SPIN_BUTTON (margin_right_spinbutton), 0, wmax);
@@ -435,7 +452,7 @@ main(int argc, gchar **argv)
             g_signal_connect (dialog, "response", G_CALLBACK (workspace_dialog_response), NULL);
 
             /* To prevent the settings dialog to be saved in the session */
-            gdk_set_sm_client_id ("FAKE ID");
+            gdk_x11_set_sm_client_id ("FAKE ID");
 
             gtk_main ();
 
@@ -448,11 +465,11 @@ main(int argc, gchar **argv)
 
             /* Get plug child widget */
             plug_child = GTK_WIDGET (gtk_builder_get_object (builder, "plug-child"));
-            gtk_widget_reparent (plug_child, plug);
+            xfwm_widget_reparent (plug_child, plug);
             gtk_widget_show (plug_child);
 
             /* To prevent the settings dialog to be saved in the session */
-            gdk_set_sm_client_id ("FAKE ID");
+            gdk_x11_set_sm_client_id ("FAKE ID");
 
             /* Stop startup notification */
             gdk_notify_startup_complete ();
