@@ -170,7 +170,7 @@ clientCycleFocusAndRaise (Client *c)
 {
     ScreenInfo *screen_info;
     DisplayInfo *display_info;
-    Client *sibling;
+    Client *ancestor;
 
     g_return_if_fail (c != NULL);
     TRACE ("client \"%s\" (0x%lx)", c->name, c->window);
@@ -178,9 +178,9 @@ clientCycleFocusAndRaise (Client *c)
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
 
-    sibling = clientGetTransientFor(c);
-    clientRaise (sibling, None);
-    clientShow (sibling, TRUE);
+    ancestor = clientGetTransientFor(c);
+    clientRaise (c, None);
+    clientShow (ancestor, TRUE);
     clientUnshade (c);
     clientSetFocus (screen_info, c, myDisplayGetCurrentTime (display_info), NO_FOCUS_FLAG);
     clientSetLastRaise (c);
@@ -251,7 +251,7 @@ clientCycleEventFilter (XfwmEvent *event, gpointer data)
     eventFilterStatus status;
     KeyCode cancel, left, right, up, down;
     int key, modifiers;
-    gboolean cycling, gone;
+    gboolean cycling;
     GList *li;
 
     TRACE ("entering");
@@ -275,7 +275,6 @@ clientCycleEventFilter (XfwmEvent *event, gpointer data)
     status = EVENT_FILTER_CONTINUE;
     removed = NULL;
     cycling = TRUE;
-    gone = FALSE;
 
     /* Update the display time */
     myDisplayUpdateCurrentTime (display_info, event);
@@ -335,7 +334,7 @@ clientCycleEventFilter (XfwmEvent *event, gpointer data)
             }
             else
             {
-                int keysym = XkbKeycodeToKeysym (event->meta.x->xany.display, event->key.keycode, 0, 0);
+                int keysym = XkbKeycodeToKeysym (event->meta.xevent->xany.display, event->key.keycode, 0, 0);
 
                 if (IsModifierKey(keysym))
                 {
@@ -395,23 +394,33 @@ clientCycleEventFilter (XfwmEvent *event, gpointer data)
             }
             status = EVENT_FILTER_STOP;
             break;
-        case XFWM_EVENT_X:
-            switch (event->meta.x->type)
+        case XFWM_EVENT_XEVENT:
+            switch (event->meta.xevent->type)
             {
                 case DestroyNotify:
                     status = EVENT_FILTER_CONTINUE;
-                    if ((removed = myScreenGetClientFromWindow (screen_info, ((XDestroyWindowEvent *) event->meta.x)->window, SEARCH_WINDOW)) == NULL)
+                    removed = myScreenGetClientFromWindow (screen_info,
+                                                           ((XDestroyWindowEvent *) event->meta.xevent)->window,
+                                                           SEARCH_WINDOW);
+                    if (removed == NULL)
+                    {
                         break; /* No need to go any further */
-                    gone |= (c == removed);
+                    }
                     FALLTHROUGH;
                 case UnmapNotify:
                     status = EVENT_FILTER_CONTINUE;
-                    if (!removed && (removed = myScreenGetClientFromWindow (screen_info, ((XUnmapEvent *) event->meta.x)->window, SEARCH_WINDOW)) == NULL)
-                        break; /* No need to go any further */
-                    gone |= (c == removed);
+                    if (!removed)
+                    {
+                        removed = myScreenGetClientFromWindow (screen_info,
+                                                               ((XUnmapEvent *) event->meta.xevent)->window,
+                                                               SEARCH_WINDOW);
+                        if (removed == NULL)
+                        {
+                            break; /* No need to go any further */
+                        }
+                    }
                     c = tabwinRemoveClient(passdata->tabwin, removed);
                     cycling = clientCycleUpdateWireframe (c, passdata);
-                    status = EVENT_FILTER_STOP;
                     break;
             }
             break;
