@@ -27,6 +27,8 @@
 #include <X11/extensions/XInput2.h>
 #endif
 
+#include "display.h"
+
 #ifdef HAVE_XI2
 static const struct
 {
@@ -404,11 +406,22 @@ xfwm_device_grab_button (XfwmDevices *devices, Display *display,
 {
     gboolean result;
     Status status;
+    DisplayInfo *display_info;
 #ifdef HAVE_XI2
     XIGrabModifiers xi2_modifiers;
     XIEventMask xievent_mask;
 #endif
 
+    display_info = myDisplayGetDefault ();
+    myDisplayErrorTrapPush (display_info);
+    result = XGrabButton (display, button, modifiers, grab_window,
+                          owner_events, event_mask, grab_mode, paired_device_mode,
+                          confine_to, cursor);
+    if (myDisplayErrorTrapPop (display_info) || !result)
+    {
+        return FALSE;
+    }
+
 #ifdef HAVE_XI2
     if (devices->xi2_available)
     {
@@ -416,31 +429,35 @@ xfwm_device_grab_button (XfwmDevices *devices, Display *display,
         xi2_modifiers.status = 0;
 
         xfwm_device_fill_xi2_event_mask (&xievent_mask, event_mask);
+        myDisplayErrorTrapPush (display_info);
         status = XIGrabButton (display, devices->pointer.xi2_device, button, grab_window,
                                cursor, grab_mode, paired_device_mode, owner_events,
                                &xievent_mask, 1, &xi2_modifiers);
         g_free (xievent_mask.mask);
-        result = (status == XIGrabSuccess);
+        if (myDisplayErrorTrapPop (display_info) || status != XIGrabSuccess)
+        {
+            return FALSE;
+        }
     }
-    else
 #endif
-    {
-        status = XGrabButton (display, button, modifiers, grab_window,
-                              owner_events, event_mask, grab_mode, paired_device_mode,
-                              confine_to, cursor);
-        result = (status == GrabSuccess);
-    }
-    return result;
+
+    return TRUE;
 }
 
 void
 xfwm_device_ungrab_button (XfwmDevices *devices, Display *display,
                            guint button, guint modifiers, Window grab_window)
 {
+    DisplayInfo *display_info;
 #ifdef HAVE_XI2
     XIGrabModifiers xi2_modifiers;
 #endif
 
+    display_info = myDisplayGetDefault ();
+    myDisplayErrorTrapPush (display_info);
+
+    XUngrabButton (display, button, modifiers, grab_window);
+
 #ifdef HAVE_XI2
     if (devices->xi2_available)
     {
@@ -450,11 +467,9 @@ xfwm_device_ungrab_button (XfwmDevices *devices, Display *display,
         XIUngrabButton (display, devices->pointer.xi2_device, button,
                         grab_window, 1, &xi2_modifiers);
     }
-    else
 #endif
-    {
-        XUngrabButton (display, button, modifiers, grab_window);
-    }
+
+    myDisplayErrorTrapPopIgnored (display_info);
 }
 
 gboolean
@@ -465,11 +480,21 @@ xfwm_device_grab_keycode (XfwmDevices *devices, Display *display,
 {
     gboolean result;
     Status status;
+    DisplayInfo *display_info;
 #ifdef HAVE_XI2
     XIGrabModifiers xi2_modifiers;
     XIEventMask xievent_mask;
 #endif
 
+    display_info = myDisplayGetDefault ();
+    myDisplayErrorTrapPush (display_info);
+    result = XGrabKey (display, keycode, modifiers, grab_window,
+                       owner_events, grab_mode, paired_device_mode);
+    if (myDisplayErrorTrapPop (display_info) || !result)
+    {
+        return FALSE;
+    }
+
 #ifdef HAVE_XI2
     if (devices->xi2_available)
     {
@@ -477,30 +502,35 @@ xfwm_device_grab_keycode (XfwmDevices *devices, Display *display,
         xi2_modifiers.status = 0;
 
         xfwm_device_fill_xi2_event_mask (&xievent_mask, event_mask);
+        myDisplayErrorTrapPush (display_info);
         status = XIGrabKeycode (display, devices->keyboard.xi2_device, keycode, grab_window,
                                 grab_mode, paired_device_mode, owner_events,
                                 &xievent_mask, 1, &xi2_modifiers);
         g_free (xievent_mask.mask);
-        result = (status == XIGrabSuccess);
+        if (myDisplayErrorTrapPop (display_info) || status != XIGrabSuccess)
+        {
+            return FALSE;
+        }
     }
-    else
 #endif
-    {
-        status = XGrabKey (display, keycode, modifiers, grab_window,
-                           owner_events, grab_mode, paired_device_mode);
-        result = (status == GrabSuccess);
-    }
-    return result;
+
+    return TRUE;
 }
 
 void
 xfwm_device_ungrab_keycode (XfwmDevices *devices, Display *display,
                             gint keycode, guint modifiers, Window grab_window)
 {
+    DisplayInfo *display_info;
 #ifdef HAVE_XI2
     XIGrabModifiers xi2_modifiers;
 #endif
 
+    display_info = myDisplayGetDefault ();
+    myDisplayErrorTrapPush (display_info);
+
+    XUngrabKey (display, keycode, modifiers, grab_window);
+
 #ifdef HAVE_XI2
     if (devices->xi2_available)
     {
@@ -510,11 +540,9 @@ xfwm_device_ungrab_keycode (XfwmDevices *devices, Display *display,
         XIUngrabKeycode (display, devices->keyboard.xi2_device, keycode,
                          grab_window, 1, &xi2_modifiers);
     }
-    else
 #endif
-    {
-        XUngrabKey (display, keycode, modifiers, grab_window);
-    }
+
+    myDisplayErrorTrapPopIgnored (display_info);
 }
 
 #ifdef HAVE_XI2
