@@ -901,7 +901,7 @@ gboolean
 myDisplayTestXrender (DisplayInfo *display, gdouble min_time)
 {
 #ifdef HAVE_RENDER
-    GTimeVal t1, t2;
+    gint64 t1, t2;
     gdouble dt;
     Display *dpy;
     Picture picture1, picture2, picture3;
@@ -971,7 +971,7 @@ myDisplayTestXrender (DisplayInfo *display, gdouble min_time)
                                 DefaultRootWindow(dpy),
                                 1, 1, 8);
 
-    g_get_current_time (&t1);
+    t1 = g_get_monotonic_time ();
 
     pa.repeat = TRUE;
     picture1 = XRenderCreatePicture (dpy,
@@ -1011,10 +1011,8 @@ myDisplayTestXrender (DisplayInfo *display, gdouble min_time)
 
     XDestroyWindow (dpy, output);
 
-    g_get_current_time (&t2);
-
-    dt = (gdouble) (t2.tv_sec - t1.tv_sec) * G_USEC_PER_SEC +
-         (gdouble) (t2.tv_usec - t1.tv_usec) / 1000.0;
+    t2 = g_get_monotonic_time ();
+    dt = (gdouble) (t2 - t1) / 1000.0;
 
     if (dt < min_time)
     {
