@@ -1619,11 +1619,6 @@ handleFocusIn (DisplayInfo *display_info, XFocusChangeEvent * ev)
                 }
             }
         }
-
-        if (screen_info->params->raise_on_focus)
-        {
-            clientResetDelayedRaise (screen_info);
-        }
     }
 
     return EVENT_FILTER_REMOVE;
@@ -2772,7 +2767,6 @@ refresh_font_cb (GObject * obj, GdkEvent * ev, gpointer data)
     for (list = display_info->screens; list; list = g_slist_next (list))
     {
         ScreenInfo *screen_info = (ScreenInfo *) list->data;
-        myScreenUpdateFontHeight (screen_info);
         clientUpdateAllFrames (screen_info, UPDATE_FRAME);
     }
 
