@@ -527,8 +527,15 @@ clientUpdateFocus (ScreenInfo *screen_info, Client * c, unsigned short flags)
 
         if (!restacked && screen_info->params->raise_on_focus)
         {
-            clientRaise (c, None);
-            clientSetLastRaise (c);
+            if (screen_info->params->click_to_focus)
+            {
+                clientRaise (c, None);
+                clientSetLastRaise (c);
+            }
+            else
+            {
+                clientResetDelayedRaise (screen_info);
+            }
         }
         frameQueueDraw (c, FALSE);
         clientUpdateOpacity (c);
@@ -709,7 +716,6 @@ clientGrabMouseButton (Client * c)
     TRACE ("client \"%s\" (0x%lx)", c->name, c->window);
 
     screen_info = c->screen_info;
-    myDisplayErrorTrapPush (screen_info->display_info);
     if (screen_info->params->raise_with_any_button)
     {
         grabButton (screen_info->display_info->devices, clientGetXDisplay (c),
@@ -720,7 +726,6 @@ clientGrabMouseButton (Client * c)
         grabButton (screen_info->display_info->devices, clientGetXDisplay (c),
                     Button1, AnyModifier, c->window);
     }
-    myDisplayErrorTrapPopIgnored (screen_info->display_info);
 }
 
 void
@@ -729,12 +734,10 @@ clientUngrabMouseButton (Client * c)
     g_return_if_fail (c != NULL);
     TRACE ("client \"%s\" (0x%lx)", c->name, c->window);
 
-    myDisplayErrorTrapPush (c->screen_info->display_info);
     ungrabButton (c->screen_info->display_info->devices, clientGetXDisplay (c),
                   AnyButton, AnyModifier, c->window);
     /* We've ungrabbed way too much, so regrab the regular buttons/modifiers */
     clientGrabButtons (c);
-    myDisplayErrorTrapPopIgnored (c->screen_info->display_info);
 }
 
 void
