@@ -89,7 +89,7 @@ enum {
 };
 
 static gint compositor = COMPOSITOR_MODE_MANUAL;
-static gint vblank_method = VBLANK_AUTO;
+static vblankMode vblank_mode = VBLANK_AUTO;
 #define XFWM4_ERROR      (xfwm4_error_quark ())
 
 #ifndef DEBUG
@@ -465,9 +465,9 @@ compositor_callback (const gchar  *name,
 
 static gboolean
 vblank_callback (const gchar  *name,
-                     const gchar  *value,
-                     gpointer      user_data,
-                     GError      **error)
+                 const gchar  *value,
+                 gpointer      user_data,
+                 GError      **error)
 {
     gboolean succeed = TRUE;
 
@@ -476,20 +476,20 @@ vblank_callback (const gchar  *name,
 #ifdef HAVE_PRESENT_EXTENSION
     if (strcmp (value, "xpresent") == 0)
     {
-        vblank_method = VBLANK_XPRESENT;
+        vblank_mode = VBLANK_XPRESENT;
     }
     else
 #endif /* HAVE_PRESENT_EXTENSION */
 #ifdef HAVE_EPOXY
     if (strcmp (value, "glx") == 0)
     {
-        vblank_method = VBLANK_GLX;
+        vblank_mode = VBLANK_GLX;
     }
     else
 #endif /* HAVE_EPOXY */
     if (strcmp (value, "off") == 0)
     {
-        vblank_method = VBLANK_OFF;
+        vblank_mode = VBLANK_OFF;
     }
     else
     {
@@ -537,7 +537,6 @@ initialize (gint compositor_mode, gboolean replace_wm)
     {
         display_info->enable_compositor = FALSE;
     }
-    display_info->vblank_method = vblank_method;
     compositorSetCompositeMode (display_info, (compositor_mode == COMPOSITOR_MODE_MANUAL));
 #else /* HAVE_COMPOSITOR */
     display_info->enable_compositor = FALSE;
@@ -594,6 +593,11 @@ initialize (gint compositor_mode, gboolean replace_wm)
             return -2;
         }
 
+        if (vblank_mode != VBLANK_AUTO)
+        {
+            compositorSetVblankMode (screen_info, vblank_mode);
+        }
+
         if (compositor_mode == COMPOSITOR_MODE_AUTO)
         {
             compositorManageScreen (screen_info);
@@ -691,8 +695,15 @@ main (int argc, char **argv)
         { "daemon", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, daemon_callback, N_("Fork to the background (not supported)"), NULL },
 #ifdef HAVE_COMPOSITOR
         { "compositor", '\0', 0, G_OPTION_ARG_CALLBACK, compositor_callback, N_("Set the compositor mode"), "on|off|auto" },
-        { "vblank", '\0', 0, G_OPTION_ARG_CALLBACK, vblank_callback, N_("Set the vblank mode"), "off|present|glx" },
-#endif
+        { "vblank", '\0', 0, G_OPTION_ARG_CALLBACK, vblank_callback, N_("Set the vblank mode"), "off"
+#ifdef HAVE_PRESENT_EXTENSION
+          "|xpresent"
+#endif /* HAVE_PRESENT_EXTENSION */
+#ifdef HAVE_EPOXY
+          "|glx"
+#endif /* HAVE_EPOXY */
+        },
+#endif /* HAVE_COMPOSITOR */
         { "replace", '\0', 0, G_OPTION_ARG_NONE, &replace_wm, N_("Replace the existing window manager"), NULL },
         { "version", 'V', 0, G_OPTION_ARG_NONE, &version, N_("Print version information and exit"), NULL },
         { NULL }
@@ -703,6 +714,28 @@ main (int argc, char **argv)
 #endif /* DEBUG */
     DBG ("xfwm4 starting");
 
+#ifdef HAVE_EPOXY
+    /* NVIDIA proprietary/closed source driver queues up to 2 frames by
+     * default before blocking in glXSwapBuffers(), whereas our compositor
+     * expects `glXSwapBuffers()` to block until the next vblank.
+     *
+     * To avoid that, our compositor was issuing a `glXWaitGL()` immediately
+     * after the call to `glXSwapBuffers()` but that translates as a busy
+     * wait, hence dramatically increasing CPU usage of xfwm4 with the
+     * NVIDIA proprietary/closed source driver.
+     *
+     * Instruct the NVIDIA proprietary/closed source driver to allow only
+     * 1 frame using the environment variable “__GL_MaxFramesAllowed” so
+     * that it matches our expectations.
+     *
+     * This must be set before libGL is loaded, hence before gtk_init().
+     *
+     * Taken from similar patch posted by NVIDIA developer for kwin:
+     * https://phabricator.kde.org/D19867
+     */
+    g_setenv("__GL_MaxFramesAllowed", "1", TRUE);
+#endif /* HAVE_EPOXY */
+
     xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
     /* xfwm4 is an X11 window manager, no point in trying to connect to
