@@ -134,9 +134,12 @@ clientSetNetState (Client * c)
         TRACE ("focused");
         data[i++] = display_info->atoms[NET_WM_STATE_FOCUSED];
     }
+
+    myDisplayErrorTrapPush (display_info);
     XChangeProperty (display_info->dpy, c->window,
                      display_info->atoms[NET_WM_STATE], XA_ATOM, 32,
                      PropModeReplace, (unsigned char *) data, i);
+    myDisplayErrorTrapPopIgnored (display_info);
 }
 
 void
@@ -333,6 +336,33 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
     second = ev->data.l[2];
     mode = 0;
 
+    if ((first  == display_info->atoms[NET_WM_STATE_HIDDEN]) ||
+        (second == display_info->atoms[NET_WM_STATE_HIDDEN]))
+    {
+        if ((action == NET_WM_STATE_ADD) && !FLAG_TEST (c->flags, CLIENT_FLAG_ICONIFIED))
+        {
+            if (CLIENT_CAN_HIDE_WINDOW (c))
+            {
+                clientWithdraw (c, c->win_workspace, TRUE);
+            }
+        }
+        else if ((action == NET_WM_STATE_REMOVE) && FLAG_TEST (c->flags, CLIENT_FLAG_ICONIFIED))
+        {
+            clientShow (c, TRUE);
+        }
+        else if (action == NET_WM_STATE_TOGGLE)
+        {
+            if (FLAG_TEST (c->flags, CLIENT_FLAG_ICONIFIED))
+            {
+                clientShow (c, TRUE);
+            }
+            else if (CLIENT_CAN_HIDE_WINDOW (c))
+            {
+                clientWithdraw (c, c->win_workspace, TRUE);
+            }
+        }
+    }
+
     if ((first  == display_info->atoms[NET_WM_STATE_SHADED]) ||
         (second == display_info->atoms[NET_WM_STATE_SHADED]))
     {
@@ -952,8 +982,9 @@ clientSetNetClientList (ScreenInfo * screen_info, Atom a, GList * list)
             Client *c = (Client *) index_src->data;
             *index_dest = c->window;
         }
-        XChangeProperty (myScreenGetXDisplay (screen_info), screen_info->xroot, a, XA_WINDOW, 32, PropModeReplace,
-            (unsigned char *) listw, size);
+        XChangeProperty (myScreenGetXDisplay (screen_info),
+                         screen_info->xroot, a, XA_WINDOW, 32,
+                         PropModeReplace, (unsigned char *) listw, size);
         g_free (listw);
     }
 }
@@ -969,29 +1000,29 @@ clientValidateNetStrut (Client * c)
     screen_info = c->screen_info;
     valid = TRUE;
 
-    if (c->struts[STRUTS_TOP] > screen_info->logical_height - screen_info->margins[STRUTS_BOTTOM])
+    if (c->struts[STRUTS_TOP] > screen_info->height - screen_info->margins[STRUTS_BOTTOM])
     {
-       c->struts[STRUTS_TOP] = screen_info->logical_height - screen_info->margins[STRUTS_BOTTOM];
+       c->struts[STRUTS_TOP] = screen_info->height - screen_info->margins[STRUTS_BOTTOM];
        g_warning ("Top strut value for application window 0x%lx confined to %d", c->window, c->struts[STRUTS_TOP]);
        valid = FALSE;
     }
 
-    if (c->struts[STRUTS_BOTTOM] > screen_info->logical_height - screen_info->margins[STRUTS_TOP])
+    if (c->struts[STRUTS_BOTTOM] > screen_info->height - screen_info->margins[STRUTS_TOP])
     {
-       c->struts[STRUTS_BOTTOM] = screen_info->logical_height - screen_info->margins[STRUTS_TOP];
+       c->struts[STRUTS_BOTTOM] = screen_info->height - screen_info->margins[STRUTS_TOP];
        g_warning ("Bottom strut value for application window 0x%lx confined to %d", c->window, c->struts[STRUTS_BOTTOM]);
        valid = FALSE;
     }
 
-    if (c->struts[STRUTS_LEFT] > screen_info->logical_width - screen_info->margins[STRUTS_RIGHT])
+    if (c->struts[STRUTS_LEFT] > screen_info->width - screen_info->margins[STRUTS_RIGHT])
     {
-       c->struts[STRUTS_LEFT] = screen_info->logical_height - screen_info->margins[STRUTS_RIGHT];
+       c->struts[STRUTS_LEFT] = screen_info->height - screen_info->margins[STRUTS_RIGHT];
        g_warning ("Left strut value for application window 0x%lx confined to %d", c->window, c->struts[STRUTS_LEFT]);
        valid = FALSE;
     }
-    if (c->struts[STRUTS_RIGHT] > screen_info->logical_width - screen_info->margins[STRUTS_LEFT])
+    if (c->struts[STRUTS_RIGHT] > screen_info->width - screen_info->margins[STRUTS_LEFT])
     {
-       c->struts[STRUTS_RIGHT] = screen_info->logical_height - screen_info->margins[STRUTS_LEFT];
+       c->struts[STRUTS_RIGHT] = screen_info->height - screen_info->margins[STRUTS_LEFT];
        g_warning ("Right strut value for application window 0x%lx confined to %d", c->window, c->struts[STRUTS_RIGHT]);
        valid = FALSE;
     }
@@ -1088,10 +1119,10 @@ clientGetNetStruts (Client * c)
         /* Fill(in values as for partial struts */
         c->struts[STRUTS_TOP_START_X] = c->struts[STRUTS_BOTTOM_START_X] = 0;
         c->struts[STRUTS_TOP_END_X] = c->struts[STRUTS_BOTTOM_END_X] =
-            c->screen_info->logical_width;
+            c->screen_info->width;
         c->struts[STRUTS_LEFT_START_Y] = c->struts[STRUTS_RIGHT_START_Y] = 0;
         c->struts[STRUTS_LEFT_END_Y] = c->struts[STRUTS_RIGHT_END_Y] =
-            c->screen_info->logical_height;
+            c->screen_info->height;
 
         XFree (struts);
     }
@@ -1175,8 +1206,11 @@ clientSetNetActions (Client * c)
         atoms[i++] = display_info->atoms[NET_WM_ACTION_CHANGE_DESKTOP];
         atoms[i++] = display_info->atoms[NET_WM_ACTION_STICK];
     }
+
+    myDisplayErrorTrapPush (display_info);
     XChangeProperty (clientGetXDisplay (c), c->window, display_info->atoms[NET_WM_ALLOWED_ACTIONS],
                      XA_ATOM, 32, PropModeReplace, (unsigned char *) atoms, i);
+    myDisplayErrorTrapPopIgnored (display_info);
 }
 
 void
@@ -1261,6 +1295,10 @@ clientWindowType (Client * c)
                        c->transient_for, c->window, c->name);
                 c->transient_for = c->screen_info->xroot;
             }
+            else
+            {
+                FLAG_SET (c->flags, CLIENT_FLAG_SKIP_TASKBAR);
+            }
         }
         else if (c->type_atom == display_info->atoms[NET_WM_WINDOW_TYPE_NORMAL])
         {
@@ -1311,7 +1349,7 @@ clientWindowType (Client * c)
     else
     {
         TRACE ("no \"net\" atom detected");
-        c->type = UNSET;
+        c->type = WINDOW_NORMAL;
         c->initial_layer = c->win_layer;
     }
 
@@ -1327,7 +1365,6 @@ clientWindowType (Client * c)
             c->initial_layer = c2->win_layer;
             TRACE ("applied layer is %lu", c->initial_layer);
         }
-        FLAG_UNSET (c->xfwm_flags, XFWM_FLAG_HAS_HIDE);
     }
     if (!FLAG_TEST (c->flags, CLIENT_FLAG_ABOVE|CLIENT_FLAG_BELOW|CLIENT_FLAG_FULLSCREEN))
     {
@@ -1380,7 +1417,8 @@ clientSetNetActiveWindow (ScreenInfo *screen_info, Client *c, guint32 timestamp)
     {
         data[0] = (unsigned long) c->window;
     }
-    XChangeProperty (myScreenGetXDisplay (screen_info), screen_info->xroot, display_info->atoms[NET_ACTIVE_WINDOW], XA_WINDOW, 32,
+    XChangeProperty (myScreenGetXDisplay (screen_info), screen_info->xroot,
+                     display_info->atoms[NET_ACTIVE_WINDOW], XA_WINDOW, 32,
                      PropModeReplace, (unsigned char *) data, 2);
 }
 
