@@ -35,6 +35,14 @@
 #ifndef INC_SETTINGS_H
 #define INC_SETTINGS_H
 
+#ifndef DEFAULT_THEME
+#define DEFAULT_THEME "Default"
+#endif
+
+#ifndef DEFAULT_HDPI_THEME
+#define DEFAULT_HDPI_THEME "Default-xhdpi"
+#endif
+
 enum
 {
     TITLE_SHADOW_NONE  = 0,
@@ -176,6 +184,7 @@ struct _XfwmParams
     guint easy_click;
     int focus_delay;
     int frame_opacity;
+    int frame_border_top;
     int inactive_opacity;
     int maximized_offset;
     int move_opacity;
