@@ -94,11 +94,11 @@ wireframeDrawXlib (WireFrame *wireframe, int width, int height)
         wireframe->mapped = TRUE;
 
         XDrawRectangle (myScreenGetXDisplay (screen_info), wireframe->xwindow,
-                        gdk_x11_gc_get_xgc (screen_info->white_gc),
+                        screen_info->box_gc,
                         0, 0, wireframe->width - 1, wireframe->height - 1);
 
         XDrawRectangle (myScreenGetXDisplay (screen_info), wireframe->xwindow,
-                        gdk_x11_gc_get_xgc (screen_info->white_gc),
+                        screen_info->box_gc,
                         OUTLINE_WIDTH - 1, OUTLINE_WIDTH - 1,
                         wireframe->width - 2 * (OUTLINE_WIDTH - 1) - 1,
                         wireframe->height- 2 * (OUTLINE_WIDTH - 1) - 1);
@@ -112,7 +112,7 @@ wireframeDrawXlib (WireFrame *wireframe, int width, int height)
         wireframe->mapped = TRUE;
 
         XDrawRectangle (myScreenGetXDisplay (screen_info), wireframe->xwindow,
-                        gdk_x11_gc_get_xgc (screen_info->white_gc),
+                        screen_info->box_gc,
                         0, 0, wireframe->width - 1, wireframe->height - 1);
     }
 }
@@ -161,7 +161,7 @@ wireframeUpdate (Client *c, WireFrame *wireframe)
 
     g_return_if_fail (c != NULL);
     g_return_if_fail (wireframe != NULL);
-    TRACE ("entering wireframeUpdate");
+    TRACE ("client \"%s\" (0x%lx)", c->name, c->window);
 
     wireframe->x = frameExtentX (c);
     wireframe->y = frameExtentY (c);
@@ -181,26 +181,14 @@ wireframeUpdate (Client *c, WireFrame *wireframe)
 static void
 wireframeInitColor (WireFrame *wireframe)
 {
-    ScreenInfo *screen_info;
-    gchar *color;
-    GdkColor gcolor;
+    GdkRGBA rgba;
 
-    screen_info = wireframe->screen_info;
-    color = getUIStyle  (myScreenGetGtkWidget (screen_info), "bg", "selected");
-    if (gdk_color_parse (color, &gcolor))
+    if (getUIStyleColor (myScreenGetGtkWidget (wireframe->screen_info), "bg", "selected", &rgba))
     {
-        wireframe->red   = (gdouble) gcolor.red / (gdouble) 65535;
-        wireframe->green = (gdouble) gcolor.green / (gdouble) 65535;
-        wireframe->blue  = (gdouble) gcolor.blue / (gdouble) 65535;
+        wireframe->red = rgba.red;
+        wireframe->green = rgba.green;
+        wireframe->blue = rgba.blue;
     }
-    else
-    {
-        g_warning ("Cannot parse color %s", color);
-        wireframe->red   = 0.0;
-        wireframe->green = 0.5;
-        wireframe->blue  = 1.0;
-    }
-    g_free (color);
 }
 
 WireFrame *
@@ -215,7 +203,7 @@ wireframeCreate (Client *c)
 
     g_return_val_if_fail (c != NULL, None);
 
-    TRACE ("entering wireframeCreate");
+    TRACE ("client \"%s\" (0x%lx)", c->name, c->window);
 
     screen_info = c->screen_info;
     wireframe = g_new0 (WireFrame, 1);
@@ -280,7 +268,7 @@ wireframeDelete (WireFrame *wireframe)
     ScreenInfo *screen_info;
 
     g_return_if_fail (wireframe != None);
-    TRACE ("entering wireframeDelete");
+    TRACE ("entering");
 
     screen_info = wireframe->screen_info;
     XUnmapWindow (myScreenGetXDisplay (screen_info), wireframe->xwindow);
